Breezy User Reference — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# Breezy User Reference

## About This Manual

This manual is generated from Breezy’s online help. To use the online help system, try the following commands.

> Introduction including a list of commonly used commands:

>     brz help

> List of topics and a summary of each:

>     brz help topics

> List of commands and a summary of each:

>     brz help commands

> More information about a particular topic or command:

>     brz help topic-or-command-name

The following web sites provide further information on Breezy:

Home page

  http://www.breezy-vcs.org/

Breezy docs

  http://www.breezy-vcs.org/doc/

Launchpad

  https://launchpad.net/brz/

## Concepts

- branches
- Checkouts
- Content Filters
- Criss-Cross
- Diverged Branches
- End of Line Conversion
- Storage Formats
- Patterns
- Repositories
- Rules
- Standalone Trees
- Branches Out of Sync
- Working Trees

## Lists

- Authentication Settings
- Bug Tracker Settings
- Configuration Settings
- Conflict Types
- Current Storage Formats
- Debug Flags
- Environment Variables
- Files
- Global Options
- Glossary
- Hooks
- Location aliases
- Log Formats
- Missing Extensions
- Other Storage Formats
- Revision Identifiers
- Standard Options
- Status Flags
- Special character handling in URLs
- URL Identifiers

## Commands

- add
- alias
- annotate
- bind
- bisect
- branch
- branches
- break-lock
- cat
- check
- checkout
- clean-tree
- commit
- config
- conflicts
- cp
- deleted
- diff
- export
- grep
- help
- ignore
- ignored
- import
- info
- init
- init-repository
- join
- link-tree
- log
- ls
- merge
- missing
- mkdir
- mv
- nick
- pack
- ping
- plugins
- pull
- push
- reconcile
- reconfigure
- remerge
- remove
- remove-branch
- remove-tree
- renames
- resolve
- revert
- revno
- root
- send
- serve
- shelve
- sign-my-commits
- split
- status
- switch
- tag
- tags
- testament
- unbind
- uncommit
- unshelve
- update
- upgrade
- verify-signatures
- version
- version-info
- view
- whoami